==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnLayoutDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnGroupDescriptionMetadata } from "./WebColumnGroupDescriptionMetadata";
import { WebColumnLayoutDescription } from "./WebColumnLayoutDescription";
/**
 * @hidden
 */
var WebColumnLayoutDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnLayoutDescriptionMetadata, _super);
    function WebColumnLayoutDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnLayoutDescriptionMetadata.b = function (a) {
        if (WebColumnLayoutDescriptionMetadata.a == null) {
            WebColumnLayoutDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnLayoutDescriptionMetadata.c(WebColumnLayoutDescriptionMetadata.a);
        }
        if (a.j(WebColumnLayoutDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnLayoutDescriptionMetadata.a);
    };
    WebColumnLayoutDescriptionMetadata.c = function (a) {
        WebColumnGroupDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnLayout");
        a.item("__tagNameWC", "String:igc-column-layout");
        a.item("__packageNameWC", "String:grids");
        a.item("__manageCollectionInMarkup", "Boolean");
        a.item("ChildrenVisibleIndexesRef", "(w:ChildrenVisibleIndexes,wf:ChildrenVisibleIndexes)DataRef:object");
    };
    WebColumnLayoutDescriptionMetadata.d = function (a) {
        WebColumnLayoutDescriptionMetadata.b(a);
        a.aa("WebColumnLayout", function () { return new WebColumnLayoutDescription(); });
        a.z("WebColumnLayout", WebColumnLayoutDescriptionMetadata.a);
    };
    WebColumnLayoutDescriptionMetadata.$t = markType(WebColumnLayoutDescriptionMetadata, 'WebColumnLayoutDescriptionMetadata');
    WebColumnLayoutDescriptionMetadata.a = null;
    return WebColumnLayoutDescriptionMetadata;
}(Base));
export { WebColumnLayoutDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnLayoutDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnGroupDescriptionMetadata } from "./WebColumnGroupDescriptionMetadata";
import { WebColumnLayoutDescription } from "./WebColumnLayoutDescription";
/**
 * @hidden
 */
var WebColumnLayoutDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnLayoutDescriptionMetadata, _super);
    function WebColumnLayoutDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnLayoutDescriptionMetadata.b = function (a) {
        if (WebColumnLayoutDescriptionMetadata.a == null) {
            WebColumnLayoutDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnLayoutDescriptionMetadata.c(WebColumnLayoutDescriptionMetadata.a);
        }
        if (a.k(WebColumnLayoutDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnLayoutDescriptionMetadata.a);
    };
    WebColumnLayoutDescriptionMetadata.c = function (a) {
        WebColumnGroupDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnLayout");
        a.item("__tagNameWC", "String:igc-column-layout");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__manageCollectionInMarkup", "Boolean");
        a.item("ChildrenVisibleIndexesRef", "(w:ChildrenVisibleIndexes,wf:ChildrenVisibleIndexes)DataRef:object");
    };
    WebColumnLayoutDescriptionMetadata.d = function (a) {
        WebColumnLayoutDescriptionMetadata.b(a);
        a.ac("WebColumnLayout", function () { return new WebColumnLayoutDescription(); });
        a.ab("WebColumnLayout", WebColumnLayoutDescriptionMetadata.a);
    };
    WebColumnLayoutDescriptionMetadata.$t = markType(WebColumnLayoutDescriptionMetadata, 'WebColumnLayoutDescriptionMetadata');
    WebColumnLayoutDescriptionMetadata.a = null;
    return WebColumnLayoutDescriptionMetadata;
}(Base));
export { WebColumnLayoutDescriptionMetadata };
